@@ -305,7 +305,7 @@ class EM_Field():
         prop = prop.reshape(self.__nPoints, order='F')
         
         fig, ax = plt.subplots(1,1)
-        fig.canvas.set_window_title("%s_%s_%d" %(prop_key, plane, sliceIdx))
+        fig.canvas.manager.set_window_title("%s_%s_%d" %(prop_key, plane, sliceIdx))
         fig.suptitle("%s, Index: %d" %(prop_key, sliceIdx))
         
         if plane.lower() == 'xy' or  plane.lower() == 'yz':
@@ -405,7 +405,7 @@ class EM_Field():
         fig, axs = plt.subplots(n_rows,n_cols)
         axs = np.array(axs).flatten()
         
-        fig.canvas.set_window_title("%s_%.2f MHz_%s_%d" %(em_field, freq*1e-6, plane, sliceIdx))
+        fig.canvas.manager.set_window_title("%s_%.2f MHz_%s_%d" %(em_field, freq*1e-6, plane, sliceIdx))
         fig.suptitle("%s, Component: %s, Frequency: %.2f MHz, Index: %d" %(em_field, comp, freq*1e-6, sliceIdx))
         
         for i, ax in enumerate(axs):
@@ -818,8 +818,8 @@ class EM_Field():
                                 raise EM_FieldIOError("At least one of e_field files is not compatible with the evaluated or passed nPoints", "importFields_cst")
                             e_field[idx_f, port, :, :] = (e_real+1j*e_imag).T
                         if imp_bfield:
-                            b_real = np.loadtxt(directory+"/bfield_%s_port%d.txt"%(f,port+1), skiprows=2, usecols=(3,4,5))
-                            b_imag = np.loadtxt(directory+"/bfield_%s_port%d.txt"%(f,port+1), skiprows=2, usecols=(6,7,8))
+                            b_real = np.loadtxt(directory+"/bfield_%s_port%d.txt"%(f,port+1), skiprows=2, usecols=re_cols)
+                            b_imag = np.loadtxt(directory+"/bfield_%s_port%d.txt"%(f,port+1), skiprows=2, usecols=im_cols)
                             if b_real.shape[0] != n:
                                 raise EM_FieldIOError("At least one of b_field files is not compatible with the evaluated or passed nPoints", "importFields_cst")
                             b_field[idx_f, port, :, :] = (b_real+1j*b_imag).T
